Production Environment — django-dajaxice v0.1.8 documentation

### Navigation

- index
- next |
- previous |
- django-dajaxice v0.1.8 documentation »

# Production Environment

Since `0.5` dajaxice takes advantage of `django.contrib.staticfiles` so deploying a dajaxice application live is much easy than in previous versions.

You need to remember to run `python manage.py collectstatic` before deploying your code live. This command will collect all the static files your application need into `STATIC_ROOT`. For further information, this is the Django static files docuemntation

### Navigation

- index
- next |
- previous |
- django-dajaxice v0.1.8 documentation »